#!/bin/sh

. ./build-env.sh

cd linux/

if [ ! -e .builddate ]; then
  LANG=C date -u > .builddate
fi

VERSION=`cat Makefile | grep -E '^VERSION.=' | cut -d "=" -f 2- | tr -d " \t\n\r"`
PATCHLEVEL=`cat Makefile | grep PATCHLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`
SUBVERSION=`cat Makefile | grep SUBLEVEL.= | cut -d "=" -f 2- | tr -d " \t\n\r"`
BUILDVERSION=1
BUILDTIMESTAMP=`cat .builddate`

export ARCH=arm64
export KBUILD_DEBARCH=arm64
export K_IMAGE=Image
export KBUILD_IMAGE=${K_IMAGE}
if [ "X${BSP_ARCH}" = "Xarmhf" ]; then
  export ARCH=arm
  export CROSS_COMPILE=arm-linux-gnueabihf-
  export KBUILD_DEBARCH=armhf

elif [ "X${BSP_ARCH}" = "Xamd64" ]; then
  export ARCH=x86
  export CROSS_COMPILE=x86_64-linux-gnu-
  export KBUILD_DEBARCH=amd64
  export KBUILD_IMAGE=bzImage
  export K_IMAGE=bzImage
  export KBUILD_IMAGE=arch/${ARCH}/boot/${K_IMAGE}

elif [ "X${BSP_ARCH}" = "Xi686" ]; then
  export ARCH=x86
  export CROSS_COMPILE=i686-linux-gnu-
  export KBUILD_DEBARCH=i386
  export KBUILD_IMAGE=bzImage
  export K_IMAGE=bzImage
  export KBUILD_IMAGE=arch/${ARCH}/boot/${K_IMAGE}
fi

export LOCALVERSION="+${BSP_MODEL}"
export KBUILD_BUILD_TIMESTAMP=${BUILDTIMESTAMP}
export KBUILD_BUILD_VERSION=${BUILDVERSION}
export KDEB_PKGVERSION="${VERSION}.${PATCHLEVEL}.${SUBVERSION}-20200620-${BSP_MODEL}"

echo "Building ${KDEB_PKGVERSION}..."

kmake() {
  echo ""
  echo "make $*"

  #KBUILD_IMAGE="Image"
  #KBUILD_IMAGE=${KBUILD_IMAGE}
    make $* KDEB_PKGVERSION="${KDEB_PKGVERSION}" \
  LOCALVERSION="${LOCALVERSION}" ARCH=${ARCH} CROSS_COMPILE=${CROSS_COMPILE} \
  KBUILD_BUILD_TIMESTAMP="${KBUILD_BUILD_TIMESTAMP}" KBUILD_BUILD_VERSION=${KBUILD_BUILD_VERSION} \
  KBUILD_DEBARCH=${KBUILD_DEBARCH} \
  DEBFULLNAME="SCP" \
  DEBEMAIL="scsupport@detc.local"
}

kmake -j4 ${K_IMAGE} modules
kmake dtbs

kmake headers_check 
kmake scripts

dtm=none
dtb=none.dtb

for m in '/*'${BSP_DTS} ${BSP_DTS} '/*odroid' '/*rockpro64' '/*rock64' 'rock2' ; do
  if [ ! -e $dtb ]; then
    dtm=$m
    for f in arch/$ARCH/boot/dts/*${dtm}*.dtb; do
      if [ -e $f ]; then
        if ! echo $f | grep -q android ; then
          dtb=$f
        fi
      fi
    done
  fi
done

if [ -e scripts/package/.builddeb.template ]; then
  cp -p scripts/package/.builddeb.template scripts/package/builddeb
else
  cp -p scripts/package/builddeb scripts/package/.builddeb.template
fi

#if [ -e arch/${ARCH}/boot/dts ]; then
#  patch -p1 < ../patches/linux-4.4.y-rk-debpkg-add-dts.patch
#fi

if [ -e $dtb ]; then
  if grep -q -E '/\*odroid' scripts/package/builddeb ; then
    sed -i "s|/\*odroid|${dtm}|g" scripts/package/builddeb
  fi
fi

#kmake -j1 deb-pkg 
kmake -j1 bindeb-pkg

cd ..

bash -e build-vdec-fw.sh

mkdir -p dbg
mv linux-*${BSP_MODEL}*-dbg*_${KDEB_PKGVERSION}_*.deb dbg/ || true

if [ -e .install-dtb.sh.template ]; then
  cp -p .install-dtb.sh.template install-dtb.sh
else
  cp -p install-dtb.sh .install-dtb.sh.template
fi
if [ -e .install-linux.sh.template ]; then
  cp -p .install-linux.sh.template install-linux.sh
else
  cp -p install-linux.sh .install-linux.sh.template
fi

if [ -e linux/$dtb ]; then
  echo "Using $dtb"
  dts=`basename $dtb`
  dts=${dts/.dtb/}


  if grep -q meson-gxbb-odroidc2 install-dtb.sh ; then
    sed -i "s|meson-gxbb-odroidc2|${dts}|g" install-dtb.sh

  elif grep -q rk3399-odroidn1-linux install-dtb.sh ; then
    sed -i "s|rk3399-odroidn1-linux|${dts}|g" install-dtb.sh
  fi

  if grep -q -E '\*c2\*' install-linux.sh ; then
    sed -i "s|\*c2\*|${dts}|g" install-linux.sh
    sed -i "s|-c2\*_|-${BSP_MODEL}*_|g" install-linux.sh
    sed -i "s|\*c2_|\*${BSP_MODEL}_|g" install-linux.sh
    sed -i "s|_arm64\.deb|_${KBUILD_DEBARCH}.deb|g" install-linux.sh

  elif grep -q -E '\*n1\*' install-linux.sh ; then
    sed -i "s|\*n1\*|${dts}|g" install-linux.sh
    sed -i "s|-n1\*_|-${BSP_MODEL}*_|g" install-linux.sh
    sed -i "s|_arm64\.deb|_${KBUILD_DEBARCH}.deb|g" install-linux.sh
  fi

else
  if grep -q -E '\*c2\*' install-linux.sh ; then
    sed -i "s|-c2\*_|-${BSP_MODEL}*_|g" install-linux.sh
    sed -i "s|\*c2_|\*${BSP_MODEL}_|g" install-linux.sh
    sed -i "s|_arm64\.deb|_${KBUILD_DEBARCH}.deb|g" install-linux.sh

  elif grep -q -E '\*n1\*' install-linux.sh ; then
    sed -i "s|-n1\*_|-${BSP_MODEL}*_|g" install-linux.sh
    sed -i "s|_arm64\.deb|_${KBUILD_DEBARCH}.deb|g" install-linux.sh
  fi
fi

echo linux-image-${KDEB_PKGVERSION}-${KBUILD_DEBARCH}.zip
zip linux-image-${KDEB_PKGVERSION}-${KBUILD_DEBARCH}.zip \
  install-linux.sh install-dtb.sh install-image.sh install-uinitrd.sh \
  linux-*_${KDEB_PKGVERSION}_*.deb meson-vdec-firmware_*_${KBUILD_DEBARCH}.deb

